#import <Foundation/Foundation.h>
#import <expat.h>

@interface ExpatXMLParser : NSObject
{
	id delegate;
	BOOL shouldProcessNamespaces;
	BOOL shouldReportNamespacePrefixes;
	BOOL shouldResolveExternalEntities;
	
	XML_Parser parser;
	NSData *data;
	NSError *error;
}

- (id)initWithContentsOfURL:(NSURL *)url;
- (id)initWithData:(NSData *)data;

- (id)delegate;
- (void)setDelegate:(id)delegate;

- (void)setShouldProcessNamespaces:(BOOL)shouldProcessNamespaces;
- (BOOL)shouldProcessNamespaces;

- (void)setShouldReportNamespacePrefixes:(BOOL)flag;
- (BOOL)shouldReportNamespacePrefixes;

- (void)setShouldResolveExternalEntities:(BOOL)shouldResolveExternalEntities;
- (BOOL)shouldResolveExternalEntities;

- (BOOL)parse;
- (void)abortParsing;
- (NSError *)parserError;

- (int)columnNumber;
- (int)lineNumber;
- (NSString *)publicID;
- (NSString *)systemID;

@end


// Delegate Methods
@interface NSObject (ExpatXMLParserDelegate)

- (void)parserDidStartDocument:(id)parser;
- (void)parserDidEndDocument:(id)parser;

- (void)parser:(id)parser didStartElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qualifiedName attributes:(NSDictionary *)attributeDict;
- (void)parser:(id)parser didEndElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName;

- (void)parser:(id)parser didStartMappingPrefix:(NSString *)prefix toURI:(NSString *)namespaceURI;
- (void)parser:(id)parser didEndMappingPrefix:(NSString *)prefix;

- (void)parser:(id)parser foundCharacters:(NSString *)string;

- (void)parser:(id)parser foundComment:(NSString *)comment;

- (void)parser:(id)parser foundProcessingInstructionWithTarget:(NSString *)target data:(NSString *)data;

- (void)parser:(id)parser parseErrorOccurred:(NSError *)parseError;

@end