#import "MainController.h"
#import "ExpatXMLParser.h"

@implementation MainController

- (IBAction)parse:(id)sender
{
	id mpr;
	NSString *xmlPath;
	
	NSLog(@"Parsing now...");
	
	// This is a simple XML file that contains made up medical information
	xmlPath = [[NSBundle mainBundle] pathForResource:@"patients" ofType:@"xml"];
	
	// Your iTunes Music Library xml file
	//xmlPath = [NSHomeDirectory() stringByAppendingString:@"/Music/iTunes/iTunes Music Library.xml"];
	
	// This is a XML file with namespaces. It was copied and pasted from a tutorial on xml.com
	//xmlPath = [[NSBundle mainBundle] pathForResource:@"ns" ofType:@"xml"];
	
	printf("%s \n", [xmlPath cString]);
	NSURL *xmlURL = [NSURL fileURLWithPath:xmlPath];
	
	// Uncomment the following line to see the results if using the built-in parser
	//mpr = [[NSXMLParser alloc] initWithContentsOfURL:xmlURL];
	
	// Uncomment the following line to see the results if using the expat parser
	mpr = [[ExpatXMLParser alloc] initWithContentsOfURL:xmlURL];
	
	//[mpr setShouldProcessNamespaces:YES];
	//[mpr setShouldReportNamespacePrefixes:YES];
	[mpr setDelegate:self];
	
	//Record current time
	NSDate *start = [NSDate date];
	
	// Parse xml file
	[mpr parse];
	
	// Output parse time
	printf("Parsing time: %f seconds \n", -1*[start timeIntervalSinceNow]);
	
	[mpr release];
}

- (void)parserDidStartDocument:(id)parser
{
	printf("parserDidStartDocument \n");
}

- (void)parser:(id)parser didStartMappingPrefix:(NSString *)prefix toURI:(NSString *)namespaceURI
{
	printf("Mapping: '%s' -> %s \n", [prefix cString], [namespaceURI cString]);
}

- (void)parser:(id)parser didEndMappingPrefix:(NSString *)prefix
{
	printf("Done Mapping: '%s' \n", [prefix cString]);
}

- (void)parser:(id)parser didStartElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qualifiedName attributes:(NSDictionary *)attributeDict
{
	int i;
	for(i=0; i<depth; i++)
		printf("  ");
	printf("%i,%i: %s", [parser lineNumber], [parser columnNumber], [elementName cString]);
	
	if(namespaceURI || qualifiedName)
		printf(" (%s=%s)", [qualifiedName cString], [namespaceURI cString]);
	
	NSEnumerator *enumerator = [attributeDict keyEnumerator];
	id key;
	while ((key = [enumerator nextObject]))
	{
		printf(" %s='%s'", [key cString], [[attributeDict objectForKey:key] cString]);
	}
	printf("\n");
	
	depth++;
}

- (void)parser:(id)parser foundCharacters:(NSString *)string
{
	//printf("foundCharacters\n");
}

- (void)parser:(id)parser didEndElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName
{
	depth--;
}

- (void)parserDidEndDocument:(id)parser
{
	printf("parserDidEndDocument\n");
}

@end